# puffins: tools I use in large-scale atmospheric and climate dynamics research

Functions for computing physical quantities, convenience functions,
and more, all geared toward use in various Jupyter Notebooks for both
interactive work and for "production" work, the latter meaning to
generate figures and tables for publications and presentations.

## Getting Started

Currently this is a tool for myself.  Feel free to use it, but I
promise no support nor can I take any responsibility for any bugs or
errors in the code that may exist.

## License

This project is licensed under the Apache License - see the [LICENSE](LICENSE) file for details
